"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const pretty_1 = require("../helper/pretty");
const model_1 = require("../model");
exports.getDepthArg = (arg) => {
    const numArg = parseInt(arg, 10);
    if (!isNaN(numArg)) {
        return numArg;
    }
    exit(new Error(`Invalid "depth" argument: number expected, but got "${arg}" instead!`));
};
exports.getPrettyArg = (arg) => {
    if (arg === '') {
        return pretty_1.DEF_RENDERER;
    }
    if (arg in pretty_1.renderer) {
        return arg;
    }
    exit(new Error(`Invalid "pretty" argument: renderer expected, but got "${arg}" instead!\n` +
        `(pick one of the coolest renderers: "${Object.keys(pretty_1.renderer).join('", "')}")`));
};
exports.getSortArg = (arg) => {
    const numArg = parseInt(arg, 10);
    if (!isNaN(numArg) && model_1.Sorting[numArg]) {
        return numArg;
    }
    exit(new Error(`Invalid "sort" argument: expected number ${exports.getSortDesc()} but got "${arg}" instead!`));
};
exports.getSortDesc = () => {
    const desc = [];
    let i = 0;
    while (model_1.Sorting[i])
        desc.push(`${i} (${model_1.Sorting[i++]})`);
    return desc.join(', ');
};
function exit(error) {
    process.stderr.write('\n' + chalk_1.default.red(error.toString()) + '\n\n');
    process.exit(1);
}
exports.exit = exit;
