export interface IRef {
    name: string;
    path: string;
    pathname: string;
    depth: number;
    error?: any;
}
export interface IFile extends IRef {
    type: 'file';
    created: Date;
    modified: Date;
    size: number;
    ext: string;
    binary: boolean;
    content?: string;
}
export interface IDir extends IRef {
    type: 'dir';
    created: Date;
    modified: Date;
    nodes: TreeNode[];
}
export interface IOpts {
    all: boolean;
    content: boolean;
    depth: number;
    relative: boolean;
    include: string[];
    exclude: string[];
    glob: string[];
    sort: Sorting;
}
export interface IOptsParam {
    all?: boolean;
    content?: boolean;
    depth?: number;
    relative?: boolean;
    include?: string[];
    exclude?: string[];
    glob?: string[];
    sort?: Sorting;
}
export declare enum Sorting {
    Alpha = 0,
    FileFirst = 1,
    DirFirst = 2
}
export interface IStats {
    size: number;
    birthtime: Date;
    mtime: Date;
    isDirectory(): boolean;
    isFile(): boolean;
}
export interface IProviders {
    join(...paths: string[]): string;
    resolve(...pathSegments: any[]): string;
    relative(from: string, to: string): string;
    readFile(path: string, options: {
        encoding: string;
        flag?: string;
    }, callback: (err: Err, data: string) => void): void;
    readdir(path: string, callback: (err: Err, files: string[]) => void): void;
    stat(path: string, callback: (err: Err, stats: IStats) => void): void;
}
export interface ISearch {
    include?: string[];
    exclude?: string[];
    glob?: string[];
}
export interface ICtx extends ISearch {
    rootPath: string;
    getPath: (item: IRef) => string;
    path: string;
    depth: number;
}
export interface IResult {
    rootPath: string;
    tree: TreeNode[];
}
export interface IMatch {
    item: TreeNode;
    parentNodes: TreeNode[];
}
export declare type Item = IFile | IDir;
export declare type TreeNode = Item | IRef;
export declare type Event = 'item' | 'ready' | 'tree' | 'add' | 'change' | 'unlink' | 'all';
export declare type OnTree = (tree: TreeNode[]) => void;
export declare type OnItem = (item: TreeNode) => void;
export declare type OnItemCtx = (item: TreeNode, ctx: ICtx) => void;
export declare type OnAll = (event: Event, data: TreeNode[] | TreeNode, ctx?: ICtx) => void;
export declare type ProcessCb = (error: Err, tree?: TreeNode[]) => any;
export declare type Err = Error | null | undefined;
export declare type WatchFn = (rootPath: string, cb: WatchCb, debounceTime?: number) => {
    ready: Promise<void>;
    close: () => void;
};
export declare type WatchCb = (fullpaths: string[]) => void;
